## 股东人数

接口：stk_holdernumber

描述：获取上市公司股东户数数据，数据不定期公布

限量：单次最大3000,总量不限制

积分：600积分可调取，基础积分每分钟调取100次，5000积分以上频次相对较高。具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS股票代码 |
| ann_date | str | N | 公告日期 |
| enddate | str | N | 截止日期 |
| start_date | str | N | 公告开始日期 |
| end_date | str | N | 公告结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS股票代码 |
| ann_date | str | Y | 公告日期 |
| end_date | str | Y | 截止日期 |
| holder_num | int | Y | 股东户数 |

接口使用

```python
pro = ts.pro_api()

df = pro.stk_holdernumber(ts_code='300199.SZ', start_date='20160101', end_date='20181231')
```

数据示例

```python
ts_code  ann_date  end_date  holder_num
0   300199.SZ  20181025  20180930       25135
```